@@ -35,7 +35,7 @@ L<Test::Class::Moose>.
             }
         );
 
-        $test->api_ok(
+        my $result = $test->api_ok(
             'Create character',
             [
                 POST => '/character' => {
@@ -45,9 +45,16 @@ L<Test::Class::Moose>.
             ],
             {
                 status       => HTTP_OK,
-                json_content => { success => 1 },
+                json_content => {
+                    success => 1,
+                    character_id => ignore(),
+                },
             }
         );
+        is( $result->{id},
+            $test->fetch_last_character()->id,
+            'Result has a proper character ID'
+        );
     }
 
 =cut
@@ -66,7 +73,7 @@ use Test::Deep qw(cmp_deeply);
 use Test::Differences qw(eq_or_diff);
 use Test::More;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 =head1 REQUIRED METHODS
 
@@ -152,6 +159,7 @@ request as needed - e.g. to add additional authorization headers to it.
             json_content - reference to a structure we expect, to be passed to
             C<Test::Deep::cmp_deeply> (so C<Test::Deep>'s functions can be used
             to skip / ignore some methods in it).
+    Out: $json_content - if result was a valid JSON, otherwise undef
 
 Perform API C<$method> request on the C<$route> and test its output against
 C<%expected> values.
@@ -165,7 +173,7 @@ sub api_ok ( $test, $title, $request_args, $expected ) {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
     $test->_perform_request($test->_generate_request(@$request_args));
-    $test->_process_test_results( $title, $expected );
+    return $test->_process_test_results( $title, $expected );
 }
 
 sub _generate_request ($test, $method, $route, $params = undef) {
@@ -205,6 +213,7 @@ sub _perform_request ($test, $request) {
 sub _process_test_results ( $test, $title, $expected ) {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
+    my $json_content;
     subtest $title => sub {
 
         if ( exists $expected->{status} ) {
@@ -220,24 +229,23 @@ sub _process_test_results ( $test, $title, $expected ) {
         }
 
         if ( exists $expected->{json_content} ) {
-            if ( my $json_content = eval {
-                decode_json($test->api_client->content);
-            } )
-            {
-                # eq_or_diff() is only used to output diagnostics in case of a
-                # test failure.
-                my $ok = cmp_deeply(
-                    $json_content,
-                    $expected->{json_content},
-                    'Data is as expected'
-                ) or eq_or_diff($json_content, $expected->{json_content});
-            }
-            else {
+            $json_content = eval { decode_json($test->api_client->content); }
+              or do {
                 fail("We've got a proper JSON response");
-                diag( 'Got: ' . $test->api_client->response->as_string );
-            }
+                diag('Got: ' . $test->api_client->response->as_string);
+                return;
+              };
+
+            # eq_or_diff() is only used to output diagnostics in case of a
+            # test failure.
+            cmp_deeply(
+                $json_content,
+                $expected->{json_content},
+                'Data is as expected'
+            ) or eq_or_diff($json_content, $expected->{json_content});
         }
     };
+    return $json_content;
 }
 
 =head1 AUTHOR
